LogLevelExtension extension

This extension is used to add a name property to the LogLevel enum The name property returns the name of the log level For example, LogLevel.debug.name returns 'DEBUG'

on

Properties

name → String

Available on LogLevel, provided by the LogLevelExtension extension

no setter